==> foundation-design-system-0.0.1.tgz: package/sites/pages/intro.md <==
# Introduction

Foundation Design System is a collection of design tokens, components and guidelines for building cohesive UI systems within parts of [Envato](https://envato.com).

This project is based off of Salesforce's [theo](https://github.com/salesforce-ux/theo).

**Status:** Work in Progress.

### Developer Setup

1. Clone the repository:
```sh
git clone git@github.com:envato/foundation-design-system.git
```
2. Install dependencies:
```sh
$ npm i
```
3. Watch (and automatically build):
```sh
$ gulp watch
```

### Guide for writing Design Tokens
Design tokens are essential particles of a design system, specifically, they are variables that store visual design attributes. They can contain colors (hex, RGBA or other values), sizing units (pixels, rems, etc.) and many more. They're essential for creating and maintaing a consistent visual system.

```yml
  # global is required
  global:
    # category has to be defined at the top of each file
    category: "app"
  # use `imports` to import other files
  imports:
    [
      "./colors.yml",
      "./fonts.yml"
    ]
  # props is required to write `key` and `value` pairs
  props:
    e-font-size--body-base:
      value: "16px"
      # type is not used in the generated result but is required by the plugin
      # helps to categorize
      type: "font-size"
```

| Name | Description | Required |
| --- | --- | --- |
| global | meta information can be put here, will have other sub attribute | True |
| category | category attribute, can be `color`, `font` or whatever, required but not used in the output | True |
| imports | import other files | False |
| props | define your key value pair | True |
| type | type of the attribute, not used in the output but required | True |

### Maintainers
* [Fraser Xu](https://github.com/fraserxu)
* [István Huszár](https://github.com/khayman)
* [Jordan Lewis](https://github.com/jordanlewiz)
* [Karolina Szczur](https://github.com/thefoxis)
* [Paweł Gałązka](https://github.com/pawelgalazka)

### Code of Conduct
This project adheres to the Contributor Covenant [Code Of Conduct](CODE_OF_CONDUCT.md). By participating, you are expected to uphold this code. Please report unacceptable behavior to [market-foundation-dev@envato.com](mailto:market-foundation-dev@envato.com).

### License
[MIT](LICENSE)

==> foundation-design-system-0.0.2.tgz: package/sites/pages/intro.md <==
# Foundation Design System
Foundation Design System is a collection of design tokens, components and guidelines for building cohesive UI systems within parts of [Envato](https://envato.com).

This project is based off of Salesforce's [theo](https://github.com/salesforce-ux/theo).

***

**Status:** Work in Progress.

***
### Developer Setup

1. Clone the repository:
```sh
git clone git@github.com:envato/foundation-design-system.git
```
2. Install dependencies:
```sh
$ npm i
```
3. Watch (and automatically build):
```sh
$ gulp watch
```

### Usage

```sh
$ npm install @envato-foundation/foundation-design-system --save
```

#### Webpack and scss-loader example

Config loaders in `webpack.config.js`

```js
module: {
  loaders: [
    {
      test: /\.scss$/,
      loader: ExtractTextPlugin.extract('style-loader', 'css-loader', 'sass-loader')
    }
  ]
},
plugins: [
  new ExtractTextPlugin('[name].css')
],
resolve: {
  extensions: ['', '.js', '.scss'],
  root: [path.join(__dirname, './node_modules')]
}
```

And then in your code

```js
require('@envato-foundation/foundation-design-system/dist/colors.scss')
```

For a complete example please check the `example` directory.

### Deploying Design System Demo Sites

```sh
# npm run deploy
```

### Guide for creating Design Tokens
Design tokens are essential particles of a design system, specifically, they are variables that store visual design attributes. They can contain colors (hex, RGBA or other values), sizing units (pixels, rems, etc.) and many more. They're essential for creating and maintaing a consistent visual system.

```yml
  # global is required
  global:
    # category has to be defined at the top of each file
    category: "app"
  # use `imports` to import other files
  imports:
    [
      "./colors.yml",
      "./fonts.yml"
    ]
  # props is required to write `key` and `value` pairs
  props:
    font-size--body-m:
      value: "16px"
      # type is not used in the generated result but is required by the plugin
      # helps to categorize
      type: "font-size"
```

| Name | Description | Required |
| --- | --- | --- |
| global | meta information can be put here, will have other sub attribute | True |
| category | category attribute, can be `color`, `font` or whatever, required but not used in the output | True |
| imports | import other files | False |
| props | define your key value pair | True |
| type | type of the attribute, not used in the output but required | True |

### Maintainers
* [Fraser Xu](https://github.com/fraserxu)
* [István Huszár](https://github.com/khayman)
* [Jordan Lewis](https://github.com/jordanlewiz)
* [Karolina Szczur](https://github.com/thefoxis)
* [Paweł Gałązka](https://github.com/pawelgalazka)

### Code of Conduct
This project adheres to the Contributor Covenant [Code Of Conduct](CODE_OF_CONDUCT.md). By participating, you are expected to uphold this code. Please report unacceptable behavior to [market-foundation-dev@envato.com](mailto:market-foundation-dev@envato.com).

### License
[MIT](LICENSE)
